pub struct BaseAddressDetectionCommonSettings { /* private fields */ }Expand description
Settings shared by each base address detection mode.
Implementations
Sourceimpl BaseAddressDetectionCommonSettings
impl BaseAddressDetectionCommonSettings
pub fn arch(self, value: CoreArchitecture) -> Self
pub fn min_strlen(self, value: u32) -> Self
Sourcepub fn low_boundary(self, value: u64) -> Self
pub fn low_boundary(self, value: u64) -> Self
Specify the lower boundary of the base address range to test.
NOTE: The passed value must be less than the upper boundary.
Sourcepub fn high_boundary(self, value: u64) -> Self
pub fn high_boundary(self, value: u64) -> Self
Specify the upper boundary of the base address range to test.
NOTE: The passed value must be greater than the lower boundary.